package com.citra.pivot.demo;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.StringTokenizer;
import java.util.Vector;

import com.citra.table.DefaultListTableModel;

/**
 * Helper class for reading from a csv text file into a TableModel.
 */
public class OlapTableReader {
/**
 *
 */
public OlapTableReader() {
}
/**
 *
 */
protected DefaultListTableModel read(InputStream file) {
	try {

		//get a reader
		BufferedReader d = new BufferedReader(new InputStreamReader(file));

		//initialize vectors
		Vector rows = new Vector();
		Vector columns = new Vector();

		//read header
		String header = d.readLine();

		//get columns
		StringTokenizer tokenizer = new StringTokenizer(header, "\t");
		while (tokenizer.hasMoreTokens()) {
			columns.add(tokenizer.nextToken());
		}
		//now get row data
		String line;
		while ((line = d.readLine()) != null) {
			int column = 0;
			tokenizer = new StringTokenizer(line, "\t");
			Vector row = new Vector();

			while (tokenizer.hasMoreTokens()) {
				String columnName = columns.get(column++).toString();
				Object value = tokenizer.nextToken();
				if (columnName.endsWith("Date")) { //dates
					SimpleDateFormat format = new SimpleDateFormat("dd/MM/yyyy");
					try {
						Date date = format.parse(value.toString());
						value = date;
					} catch (Exception e) {
						value = null;
						e.printStackTrace();
					}
				}
				else if (columnName.equals("Quantity")) { //quantity
					value = new Integer(Integer.parseInt(value.toString()));
				}
				else if (value.toString().startsWith("$")) { //currency
					value = new Float(Float.parseFloat(value.toString().substring(1)));
				}
				else if (columnName.equals("Discount")) { //discount
					value = new Double(Double.parseDouble(value.toString()));
				}
				row.add(value);
			}
			//add row
			rows.add(row);
		}

		//create and return data model
		DefaultListTableModel p = new DefaultListTableModel(rows, columns);
		return p;
	}
	catch (IOException e) {
		e.printStackTrace();
	}
	return null;
}

/**
 *
 */
protected DefaultListTableModel createTableModel(String fileName) {
	try {
		InputStream file = getClass().getClassLoader().getResourceAsStream(fileName);
		if (file == null) {
			file = new FileInputStream(new File(fileName));
		}
		return read(file);
	} catch (IOException e) {
		e.printStackTrace();
	}
	return null;
}
}
